@@ -28,16 +28,21 @@ func TestConfigApply(t *testing.T) {
 		ProjectID:                       null.NewInt(1, true),
 		Name:                            null.NewString("Name", true),
 		Host:                            null.NewString("Host", true),
+		Timeout:                         types.NewNullDuration(5*time.Second, true),
 		LogsTailURL:                     null.NewString("LogsTailURL", true),
 		PushRefID:                       null.NewString("PushRefID", true),
 		WebAppURL:                       null.NewString("foo", true),
 		NoCompress:                      null.NewBool(true, true),
 		StopOnError:                     null.NewBool(true, true),
-		Timeout:                         types.NewNullDuration(5*time.Second, true),
 		APIVersion:                      null.NewInt(2, true),
 		MaxMetricSamplesPerPackage:      null.NewInt(2, true),
+		MaxTimeSeriesInBatch:            null.NewInt(3, true),
 		MetricPushInterval:              types.NewNullDuration(1*time.Second, true),
 		MetricPushConcurrency:           null.NewInt(3, true),
+		TracesEnabled:                   null.NewBool(true, true),
+		TracesHost:                      null.NewString("TracesHost", true),
+		TracesPushInterval:              types.NewNullDuration(10*time.Second, true),
+		TracesPushConcurrency:           null.NewInt(6, true),
 		AggregationPeriod:               types.NewNullDuration(2*time.Second, true),
 		AggregationCalcInterval:         types.NewNullDuration(3*time.Second, true),
 		AggregationWaitPeriod:           types.NewNullDuration(4*time.Second, true),
