@@ -35,23 +35,89 @@ type Trail struct {
 
 	Failed null.Bool
 	// Populated by SaveSamples()
-	Tags    *metrics.SampleTags
-	Samples []metrics.Sample
+	Tags     *metrics.TagSet
+	Metadata map[string]string
+	Samples  []metrics.Sample
 }
 
 // SaveSamples populates the Trail's sample slice so they're accesible via GetSamples()
-func (tr *Trail) SaveSamples(builtinMetrics *metrics.BuiltinMetrics, tags *metrics.SampleTags) {
-	tr.Tags = tags
+func (tr *Trail) SaveSamples(builtinMetrics *metrics.BuiltinMetrics, ctm *metrics.TagsAndMeta) {
+	tr.Tags = ctm.Tags
+	tr.Metadata = ctm.Metadata
 	tr.Samples = make([]metrics.Sample, 0, 9) // this is with 1 more for a possible HTTPReqFailed
 	tr.Samples = append(tr.Samples, []metrics.Sample{
-		{Metric: builtinMetrics.HTTPReqs, Time: tr.EndTime, Tags: tags, Value: 1},
-		{Metric: builtinMetrics.HTTPReqDuration, Time: tr.EndTime, Tags: tags, Value: metrics.D(tr.Duration)},
-		{Metric: builtinMetrics.HTTPReqBlocked, Time: tr.EndTime, Tags: tags, Value: metrics.D(tr.Blocked)},
-		{Metric: builtinMetrics.HTTPReqConnecting, Time: tr.EndTime, Tags: tags, Value: metrics.D(tr.Connecting)},
-		{Metric: builtinMetrics.HTTPReqTLSHandshaking, Time: tr.EndTime, Tags: tags, Value: metrics.D(tr.TLSHandshaking)},
-		{Metric: builtinMetrics.HTTPReqSending, Time: tr.EndTime, Tags: tags, Value: metrics.D(tr.Sending)},
-		{Metric: builtinMetrics.HTTPReqWaiting, Time: tr.EndTime, Tags: tags, Value: metrics.D(tr.Waiting)},
-		{Metric: builtinMetrics.HTTPReqReceiving, Time: tr.EndTime, Tags: tags, Value: metrics.D(tr.Receiving)},
+		{
+			TimeSeries: metrics.TimeSeries{
+				Metric: builtinMetrics.HTTPReqs,
+				Tags:   ctm.Tags,
+			},
+			Time:     tr.EndTime,
+			Metadata: ctm.Metadata,
+			Value:    1,
+		},
+		{
+			TimeSeries: metrics.TimeSeries{
+				Metric: builtinMetrics.HTTPReqDuration,
+				Tags:   ctm.Tags,
+			},
+			Time:     tr.EndTime,
+			Metadata: ctm.Metadata,
+			Value:    metrics.D(tr.Duration),
+		},
+		{
+			TimeSeries: metrics.TimeSeries{
+				Metric: builtinMetrics.HTTPReqBlocked,
+				Tags:   ctm.Tags,
+			},
+			Time:     tr.EndTime,
+			Metadata: ctm.Metadata,
+			Value:    metrics.D(tr.Blocked),
+		},
+		{
+			TimeSeries: metrics.TimeSeries{
+				Metric: builtinMetrics.HTTPReqConnecting,
+				Tags:   ctm.Tags,
+			},
+			Time:     tr.EndTime,
+			Metadata: ctm.Metadata,
+			Value:    metrics.D(tr.Connecting),
+		},
+		{
+			TimeSeries: metrics.TimeSeries{
+				Metric: builtinMetrics.HTTPReqTLSHandshaking,
+				Tags:   ctm.Tags,
+			},
+			Time:     tr.EndTime,
+			Metadata: ctm.Metadata,
+			Value:    metrics.D(tr.TLSHandshaking),
+		},
+		{
+			TimeSeries: metrics.TimeSeries{
+				Metric: builtinMetrics.HTTPReqSending,
+				Tags:   ctm.Tags,
+			},
+			Time:     tr.EndTime,
+			Metadata: ctm.Metadata,
+			Value:    metrics.D(tr.Sending),
+		},
+		{
+			TimeSeries: metrics.TimeSeries{
+				Metric: builtinMetrics.HTTPReqWaiting,
+				Tags:   ctm.Tags,
+			},
+			Time:     tr.EndTime,
+			Metadata: ctm.Metadata,
+			Value:    metrics.D(tr.Waiting),
+		},
+		{
+			TimeSeries: metrics.TimeSeries{
+				Metric: builtinMetrics.HTTPReqReceiving,
+				Tags:   ctm.Tags,
+			},
+			Time:     tr.EndTime,
+			Metadata: ctm.Metadata,
+			Value:    metrics.D(tr.Receiving),
+		},
 	}...)
 }
 
@@ -61,7 +127,7 @@ func (tr *Trail) GetSamples() []metrics.Sample {
 }
 
 // GetTags implements the metrics.ConnectedSampleContainer interface.
-func (tr *Trail) GetTags() *metrics.SampleTags {
+func (tr *Trail) GetTags() *metrics.TagSet {
 	return tr.Tags
 }
 
